wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body

View Source

      1from typing import Any, Dict, List, Type, TypeVar, Union
      2
      3import attr
      4
      5from ..models.v1_task_get_by_status_and_workspace_json_body_task_status_type_0 import \
      6    V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0
      7from ..models.v1_task_get_by_status_and_workspace_json_body_task_status_type_1 import \
      8    V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1
      9from ..models.v1_task_get_by_status_and_workspace_json_body_task_status_type_2 import \
     10    V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2
     11from ..models.v1_task_get_by_status_and_workspace_json_body_task_status_type_3 import \
     12    V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3
     13from ..models.v1_task_get_by_status_and_workspace_json_body_task_status_type_4 import \
     14    V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4
     15from ..models.v1_task_get_by_status_and_workspace_json_body_task_status_type_5 import \
     16    V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5
     17from ..models.v1_task_get_by_status_and_workspace_json_body_task_status_type_6 import \
     18    V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6
     19from ..models.v1_task_get_by_status_and_workspace_json_body_task_status_type_7 import \
     20    V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7
     21
     22T = TypeVar("T", bound="V1TaskGetByStatusAndWorkspaceJsonBody")
     23
     24@attr.s(auto_attribs=True)
     25class V1TaskGetByStatusAndWorkspaceJsonBody:
     26    """ Body for request to /tasks/get_by_id
     27
     28    Attributes:
     29        task_status (Union[V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0,
     30            V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2,
     31            V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4,
     32            V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6,
     33            V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7]):  The Task Status to find i.e. Failing.
     34        workspace_id (int):  Thw owning workspace id.
     35    """
     36
     37    task_status: Union[V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7]
     38    workspace_id: int
     39    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
     40
     41
     42    def to_dict(self) -> Dict[str, Any]:
     43        task_status: Union[Dict[str, Any], str]
     44
     45        if isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0):
     46            task_status = self.task_status.value
     47
     48        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1):
     49            task_status = self.task_status.value
     50
     51        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2):
     52            task_status = self.task_status.value
     53
     54        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3):
     55            task_status = self.task_status.value
     56
     57        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4):
     58            task_status = self.task_status.value
     59
     60        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5):
     61            task_status = self.task_status.value
     62
     63        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6):
     64            task_status = self.task_status.value
     65
     66        else:
     67            task_status = self.task_status.to_dict()
     68
     69
     70
     71        workspace_id = self.workspace_id
     72
     73        field_dict: Dict[str, Any] = {}
     74        field_dict.update(self.additional_properties)
     75        field_dict.update({
     76            "task_status": task_status,
     77            "workspace_id": workspace_id,
     78        })
     79
     80        return field_dict
     81
     82
     83
     84    @classmethod
     85    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
     86        d = src_dict.copy()
     87        def _parse_task_status(data: object) -> Union[V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7]:
     88            try:
     89                if not isinstance(data, str):
     90                    raise TypeError()
     91                task_status_type_0 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0(data)
     92
     93
     94
     95                return task_status_type_0
     96            except: # noqa: E722
     97                pass
     98            try:
     99                if not isinstance(data, str):
    100                    raise TypeError()
    101                task_status_type_1 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1(data)
    102
    103
    104
    105                return task_status_type_1
    106            except: # noqa: E722
    107                pass
    108            try:
    109                if not isinstance(data, str):
    110                    raise TypeError()
    111                task_status_type_2 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2(data)
    112
    113
    114
    115                return task_status_type_2
    116            except: # noqa: E722
    117                pass
    118            try:
    119                if not isinstance(data, str):
    120                    raise TypeError()
    121                task_status_type_3 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3(data)
    122
    123
    124
    125                return task_status_type_3
    126            except: # noqa: E722
    127                pass
    128            try:
    129                if not isinstance(data, str):
    130                    raise TypeError()
    131                task_status_type_4 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4(data)
    132
    133
    134
    135                return task_status_type_4
    136            except: # noqa: E722
    137                pass
    138            try:
    139                if not isinstance(data, str):
    140                    raise TypeError()
    141                task_status_type_5 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5(data)
    142
    143
    144
    145                return task_status_type_5
    146            except: # noqa: E722
    147                pass
    148            try:
    149                if not isinstance(data, str):
    150                    raise TypeError()
    151                task_status_type_6 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6(data)
    152
    153
    154
    155                return task_status_type_6
    156            except: # noqa: E722
    157                pass
    158            if not isinstance(data, dict):
    159                raise TypeError()
    160            task_status_type_7 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7.from_dict(data)
    161
    162
    163
    164            return task_status_type_7
    165
    166        task_status = _parse_task_status(d.pop("task_status"))
    167
    168
    169        workspace_id = d.pop("workspace_id")
    170
    171        v1_task_get_by_status_and_workspace_json_body = cls(
    172            task_status=task_status,
    173            workspace_id=workspace_id,
    174        )
    175
    176        v1_task_get_by_status_and_workspace_json_body.additional_properties = d
    177        return v1_task_get_by_status_and_workspace_json_body
    178
    179    @property
    180    def additional_keys(self) -> List[str]:
    181        return list(self.additional_properties.keys())
    182
    183    def __getitem__(self, key: str) -> Any:
    184        return self.additional_properties[key]
    185
    186    def __setitem__(self, key: str, value: Any) -> None:
    187        self.additional_properties[key] = value
    188
    189    def __delitem__(self, key: str) -> None:
    190        del self.additional_properties[key]
    191
    192    def __contains__(self, key: str) -> bool:
    193        return key in self.additional_properties

@attr.s(auto_attribs=True)
class V1TaskGetByStatusAndWorkspaceJsonBody: View Source

     25@attr.s(auto_attribs=True)
     26class V1TaskGetByStatusAndWorkspaceJsonBody:
     27    """ Body for request to /tasks/get_by_id
     28
     29    Attributes:
     30        task_status (Union[V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0,
     31            V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2,
     32            V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4,
     33            V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6,
     34            V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7]):  The Task Status to find i.e. Failing.
     35        workspace_id (int):  Thw owning workspace id.
     36    """
     37
     38    task_status: Union[V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7]
     39    workspace_id: int
     40    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
     41
     42
     43    def to_dict(self) -> Dict[str, Any]:
     44        task_status: Union[Dict[str, Any], str]
     45
     46        if isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0):
     47            task_status = self.task_status.value
     48
     49        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1):
     50            task_status = self.task_status.value
     51
     52        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2):
     53            task_status = self.task_status.value
     54
     55        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3):
     56            task_status = self.task_status.value
     57
     58        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4):
     59            task_status = self.task_status.value
     60
     61        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5):
     62            task_status = self.task_status.value
     63
     64        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6):
     65            task_status = self.task_status.value
     66
     67        else:
     68            task_status = self.task_status.to_dict()
     69
     70
     71
     72        workspace_id = self.workspace_id
     73
     74        field_dict: Dict[str, Any] = {}
     75        field_dict.update(self.additional_properties)
     76        field_dict.update({
     77            "task_status": task_status,
     78            "workspace_id": workspace_id,
     79        })
     80
     81        return field_dict
     82
     83
     84
     85    @classmethod
     86    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
     87        d = src_dict.copy()
     88        def _parse_task_status(data: object) -> Union[V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7]:
     89            try:
     90                if not isinstance(data, str):
     91                    raise TypeError()
     92                task_status_type_0 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0(data)
     93
     94
     95
     96                return task_status_type_0
     97            except: # noqa: E722
     98                pass
     99            try:
    100                if not isinstance(data, str):
    101                    raise TypeError()
    102                task_status_type_1 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1(data)
    103
    104
    105
    106                return task_status_type_1
    107            except: # noqa: E722
    108                pass
    109            try:
    110                if not isinstance(data, str):
    111                    raise TypeError()
    112                task_status_type_2 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2(data)
    113
    114
    115
    116                return task_status_type_2
    117            except: # noqa: E722
    118                pass
    119            try:
    120                if not isinstance(data, str):
    121                    raise TypeError()
    122                task_status_type_3 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3(data)
    123
    124
    125
    126                return task_status_type_3
    127            except: # noqa: E722
    128                pass
    129            try:
    130                if not isinstance(data, str):
    131                    raise TypeError()
    132                task_status_type_4 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4(data)
    133
    134
    135
    136                return task_status_type_4
    137            except: # noqa: E722
    138                pass
    139            try:
    140                if not isinstance(data, str):
    141                    raise TypeError()
    142                task_status_type_5 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5(data)
    143
    144
    145
    146                return task_status_type_5
    147            except: # noqa: E722
    148                pass
    149            try:
    150                if not isinstance(data, str):
    151                    raise TypeError()
    152                task_status_type_6 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6(data)
    153
    154
    155
    156                return task_status_type_6
    157            except: # noqa: E722
    158                pass
    159            if not isinstance(data, dict):
    160                raise TypeError()
    161            task_status_type_7 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7.from_dict(data)
    162
    163
    164
    165            return task_status_type_7
    166
    167        task_status = _parse_task_status(d.pop("task_status"))
    168
    169
    170        workspace_id = d.pop("workspace_id")
    171
    172        v1_task_get_by_status_and_workspace_json_body = cls(
    173            task_status=task_status,
    174            workspace_id=workspace_id,
    175        )
    176
    177        v1_task_get_by_status_and_workspace_json_body.additional_properties = d
    178        return v1_task_get_by_status_and_workspace_json_body
    179
    180    @property
    181    def additional_keys(self) -> List[str]:
    182        return list(self.additional_properties.keys())
    183
    184    def __getitem__(self, key: str) -> Any:
    185        return self.additional_properties[key]
    186
    187    def __setitem__(self, key: str, value: Any) -> None:
    188        self.additional_properties[key] = value
    189
    190    def __delitem__(self, key: str) -> None:
    191        del self.additional_properties[key]
    192
    193    def __contains__(self, key: str) -> bool:
    194        return key in self.additional_properties

Body for request to /tasks/get_by_id

Attributes: task_status (Union[V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7]): The Task Status to find i.e. Failing. workspace_id (int): Thw owning workspace id.

V1TaskGetByStatusAndWorkspaceJsonBody( task_status: Union[wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body_task_status_type_0.V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0, wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body_task_status_type_1.V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1, wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body_task_status_type_2.V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2, wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body_task_status_type_3.V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3, wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body_task_status_type_4.V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4, wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body_task_status_type_5.V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5, wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body_task_status_type_6.V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6, wallaroo.wallaroo_ml_ops_api_client.models.v1_task_get_by_status_and_workspace_json_body_task_status_type_7.V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7], workspace_id: int) View Source

    2def __init__(self, task_status, workspace_id):
    3    self.task_status = task_status
    4    self.workspace_id = workspace_id
    5    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class V1TaskGetByStatusAndWorkspaceJsonBody.

def to_dict(self) -> Dict[str, Any]: View Source

    43    def to_dict(self) -> Dict[str, Any]:
    44        task_status: Union[Dict[str, Any], str]
    45
    46        if isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0):
    47            task_status = self.task_status.value
    48
    49        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1):
    50            task_status = self.task_status.value
    51
    52        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2):
    53            task_status = self.task_status.value
    54
    55        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3):
    56            task_status = self.task_status.value
    57
    58        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4):
    59            task_status = self.task_status.value
    60
    61        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5):
    62            task_status = self.task_status.value
    63
    64        elif isinstance(self.task_status, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6):
    65            task_status = self.task_status.value
    66
    67        else:
    68            task_status = self.task_status.to_dict()
    69
    70
    71
    72        workspace_id = self.workspace_id
    73
    74        field_dict: Dict[str, Any] = {}
    75        field_dict.update(self.additional_properties)
    76        field_dict.update({
    77            "task_status": task_status,
    78            "workspace_id": workspace_id,
    79        })
    80
    81        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

     85    @classmethod
     86    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
     87        d = src_dict.copy()
     88        def _parse_task_status(data: object) -> Union[V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6, V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7]:
     89            try:
     90                if not isinstance(data, str):
     91                    raise TypeError()
     92                task_status_type_0 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType0(data)
     93
     94
     95
     96                return task_status_type_0
     97            except: # noqa: E722
     98                pass
     99            try:
    100                if not isinstance(data, str):
    101                    raise TypeError()
    102                task_status_type_1 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType1(data)
    103
    104
    105
    106                return task_status_type_1
    107            except: # noqa: E722
    108                pass
    109            try:
    110                if not isinstance(data, str):
    111                    raise TypeError()
    112                task_status_type_2 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType2(data)
    113
    114
    115
    116                return task_status_type_2
    117            except: # noqa: E722
    118                pass
    119            try:
    120                if not isinstance(data, str):
    121                    raise TypeError()
    122                task_status_type_3 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType3(data)
    123
    124
    125
    126                return task_status_type_3
    127            except: # noqa: E722
    128                pass
    129            try:
    130                if not isinstance(data, str):
    131                    raise TypeError()
    132                task_status_type_4 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType4(data)
    133
    134
    135
    136                return task_status_type_4
    137            except: # noqa: E722
    138                pass
    139            try:
    140                if not isinstance(data, str):
    141                    raise TypeError()
    142                task_status_type_5 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType5(data)
    143
    144
    145
    146                return task_status_type_5
    147            except: # noqa: E722
    148                pass
    149            try:
    150                if not isinstance(data, str):
    151                    raise TypeError()
    152                task_status_type_6 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType6(data)
    153
    154
    155
    156                return task_status_type_6
    157            except: # noqa: E722
    158                pass
    159            if not isinstance(data, dict):
    160                raise TypeError()
    161            task_status_type_7 = V1TaskGetByStatusAndWorkspaceJsonBodyTaskStatusType7.from_dict(data)
    162
    163
    164
    165            return task_status_type_7
    166
    167        task_status = _parse_task_status(d.pop("task_status"))
    168
    169
    170        workspace_id = d.pop("workspace_id")
    171
    172        v1_task_get_by_status_and_workspace_json_body = cls(
    173            task_status=task_status,
    174            workspace_id=workspace_id,
    175        )
    176
    177        v1_task_get_by_status_and_workspace_json_body.additional_properties = d
    178        return v1_task_get_by_status_and_workspace_json_body

additional_keys: List[str]